Exports address values of the GBA memory map locations.
Also, for some memory regions that are “blocks”, const indexing functions are provided.
Crate Layout
All info is exported at the crate root, but the various modules provide some notes about the general usage of that portion of memory.
Re-exports
pub use ewram::*;pub use iwram::*;pub use io::*;pub use palram::*;pub use vram::*;pub use oam::*;pub use rom::*;pub use sram::*;